package com.ynet.life.security.crypto;

import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeDBAccess;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.Security;
import java.sql.Connection;
import java.util.ArrayList;
import java.util.List;
import javax.crypto.Cipher;
import javax.crypto.CipherInputStream;
import javax.crypto.CipherOutputStream;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.spec.SecretKeySpec;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.bouncycastle.util.encoders.Hex;

/* loaded from: com_ynet_life_security_crypto.jar:com/ynet/life/security/crypto/AESCrypto.class */
public class AESCrypto {
    private static final String SQL_SECRET_KEY = "SELECT KEY_VALUE FROM SECRET_KEY WHERE KEY_TYPE = ?";

    static {
        try {
            if (Security.getProvider("BC") != null) {
                return;
            }
            Security.addProvider(new BouncyCastleProvider());
        } catch (Exception ex) {
            System.err.println("Cannot load security provider: BC \n" + ex.getMessage());
        }
    }

    public static String getRandomHexString(int intSize) {
        String str = "";
        for (int i = 0; i < (intSize << 1); i++) {
            int intLoc = (int) Math.floor(Math.random() * "0123456789abcdef".length());
            str = String.valueOf(str) + "0123456789abcdef".substring(intLoc, intLoc + 1);
        }
        return str;
    }

    public static SecretKeySpec getAESKeySpecFromString(String strKey) throws NoSuchAlgorithmException, InvalidKeyException {
        return new SecretKeySpec(strKey.getBytes(), "AES");
    }

    public static SecretKeySpec getKeySpecFromBytes(String strBytes) throws NoSuchAlgorithmException {
        return new SecretKeySpec(Hex.decode(strBytes.getBytes()), "AES");
    }

    public static String getAESKeyStringForJS(String strBytes) throws NoSuchAlgorithmException {
        SecretKeySpec spec = getKeySpecFromBytes(strBytes);
        return new String(Hex.encode(spec.getEncoded()));
    }

    public static String encryptForJS(String key, String text) throws Exception {
        Cipher cipher = Cipher.getInstance("AES/ECB/NoPadding", "BC");
        SecretKeySpec spec = getKeySpecFromBytes(key.toUpperCase());
        cipher.init(1, spec);
        byte[] byteEnc = cipher.doFinal(text.getBytes("UTF-8"));
        return new String(Hex.encode(byteEnc));
    }

    public static String decryptForJS(String key, String text) throws Exception {
        Cipher cipher = Cipher.getInstance("AES/ECB/NoPadding", "BC");
        SecretKeySpec spec = getKeySpecFromBytes(key.toUpperCase());
        cipher.init(2, spec);
        return new String(cipher.doFinal(Hex.decode(text.getBytes("UTF-8"))));
    }

    public static String decrypt(SecretKeySpec key, String text) throws Exception {
        Cipher cipher = Cipher.getInstance("AES");
        cipher.init(2, key);
        return new String(cipher.doFinal(Hex.decode(text.getBytes("UTF-8"))));
    }

    public static String encrypt(SecretKeySpec key, String text) throws Exception {
        Cipher cipher = Cipher.getInstance("AES");
        cipher.init(1, key);
        byte[] byteEnc = cipher.doFinal(text.getBytes("UTF-8"));
        return new String(Hex.encode(byteEnc));
    }

    public static String decrypt(String key, String text) throws Exception {
        Cipher cipher = Cipher.getInstance("AES");
        SecretKeySpec spec = getAESKeySpecFromString(key.toUpperCase());
        cipher.init(2, spec);
        return new String(cipher.doFinal(Hex.decode(text.getBytes("UTF-8"))));
    }

    public static String encrypt(String key, String text) throws Exception {
        Cipher cipher = Cipher.getInstance("AES");
        SecretKeySpec spec = getAESKeySpecFromString(key.toUpperCase());
        cipher.init(1, spec);
        byte[] byteEnc = cipher.doFinal(text.getBytes("UTF-8"));
        return new String(Hex.encode(byteEnc));
    }

    public static void encryptFile(String key, File in, File out) throws IOException, InvalidKeyException, NoSuchAlgorithmException, NoSuchPaddingException {
        Cipher aesCipher = Cipher.getInstance("AES");
        SecretKeySpec spec = getKeySpecFromBytes(key.toUpperCase());
        aesCipher.init(1, spec);
        FileInputStream is = new FileInputStream(in);
        CipherOutputStream os = new CipherOutputStream(new FileOutputStream(out), aesCipher);
        copy(is, os);
        os.close();
    }

    public static void decryptFile(String key, File in, File out) throws IOException, InvalidKeyException, NoSuchAlgorithmException, NoSuchPaddingException {
        Cipher aesCipher = Cipher.getInstance("AES");
        SecretKeySpec spec = getKeySpecFromBytes(key.toUpperCase());
        aesCipher.init(2, spec);
        CipherInputStream is = new CipherInputStream(new FileInputStream(in), aesCipher);
        FileOutputStream os = new FileOutputStream(out);
        copy(is, os);
        is.close();
        os.close();
    }

    private static void copy(InputStream is, OutputStream os) throws IOException {
        byte[] b = new byte[1024];
        while (true) {
            int i = is.read(b);
            if (i != -1) {
                os.write(b, 0, i);
            } else {
                return;
            }
        }
    }

    /* JADX WARN: Type inference failed for: r0v4, types: [java.lang.String, java.lang.Exception] */
    public static String getDecryptStr(String value, String keyType) throws GENEException {
        ?? decrypt;
        try {
            decrypt = decrypt(getKey(keyType), value);
            return decrypt;
        } catch (Exception e) {
            decrypt.printStackTrace();
            return value;
        }
    }

    public static String getKey(String keyType) throws GENEException {
        Exception exc = null;
        Connection connection = null;
        try {
            try {
                connection = LifeDBAccess.getConnection();
                List inputList = new ArrayList();
                new ArrayList();
                inputList.add(keyType);
                List resultList = LifeDBAccess.queryMultipleResult(connection, SQL_SECRET_KEY, inputList, 1);
                if (resultList.size() <= 0) {
                    LifeDBAccess.releaseConnection(connection);
                    return null;
                }
                String str = (String) ((List) resultList.get(0)).get(0);
                LifeDBAccess.releaseConnection(connection);
                return str;
            } catch (Exception e) {
                exc.printStackTrace();
                LifeDBAccess.releaseConnection(connection);
                return null;
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection(connection);
            throw th;
        }
    }

    /* JADX WARN: Type inference failed for: r0v9, types: [java.io.PrintStream, java.lang.Exception] */
    public static void main(String[] args) throws Exception {
        ?? r0;
        try {
            String enStr = encrypt(getAESKeySpecFromString("A6F84A769AAAEA3E"), "lincy@163.com|25|1|||lincy|210.55.33.48|23");
            System.out.println(enStr);
            String deStr = decrypt(getAESKeySpecFromString("A6F84A769AAAEA3E"), enStr);
            r0 = System.out;
            r0.println(deStr.replaceAll("\r\n", ""));
        } catch (Exception e) {
            r0.printStackTrace();
        }
    }
}
